use anyhow::Result;
use dbus::blocking::Connection;

use bluetooth::BluetoothInfo;
use user_info::UserInfo;
use power::PowerInfo;

mod bluetooth;
mod user_info;
mod power;

#[derive(serde::Serialize)]
struct SystemInfo {
    bluetooth: Vec<BluetoothInfo>,
    user: UserInfo,
    power: PowerInfo
}

fn main() -> Result<()> {
    let connection = Connection::new_system()?;
    let bluetooth = bluetooth::get_all_bluetooth_devices(&connection);
    let user = UserInfo::new(&connection).unwrap_or_default();
    let power = PowerInfo::new(&connection);
    let info = SystemInfo { bluetooth, user, power };
    println!("{}", serde_json::to_string(&info)?);
    Ok(())
}
