use dbus::blocking;

#[derive(serde::Serialize, Default)]
pub struct UserInfo {
    pub real_name: String,
    pub username: String,
    pub icon: String,
}

impl UserInfo {
    pub fn new(connection: &blocking::Connection) -> anyhow::Result<Self> {
        let uid = nix::unistd::Uid::current();
        let proxy = connection.with_proxy(
            "org.freedesktop.Accounts",
            format!("/org/freedesktop/Accounts/User{}", uid),
            std::time::Duration::from_millis(5000),
        );
        use blocking::stdintf::org_freedesktop_dbus::Properties;
        let icon: String = proxy.get("org.freedesktop.Accounts.User", "IconFile")?;
        let real_name: String = proxy.get("org.freedesktop.Accounts.User", "RealName")?;
        let username: String = proxy.get("org.freedesktop.Accounts.User", "UserName")?;
        Ok(Self {
            real_name,
            username,
            icon,
        })
    }
}
